Learn R Programming

otsfeatures (version 1.0.0)

ci_ordinal_skewness: Constructs a confidence interval for the ordinal skewness (block distance)

Description

ci_ordinal_skewness constructs a confidence interval for the ordinal skewness (block distance)

Usage

ci_ordinal_skewness(series, states, level = 0.95, temporal = TRUE, max_lag = 1)

Value

The confidence interval.

Arguments

series

An OTS (numerical vector with integers).

states

A numeric vector containing the corresponding states.

level

The confidence level (default is 0.95).

temporal

Logical. If temporal = TRUE (default), the interval is computed for a time series. Otherwise, the interval is computed for i.i.d. data.

max_lag

If temporal = TRUE, the maximum considered lag to compute the estimates related to the cumulative joint probabilities.

Author

Ángel López-Oriona, José A. Vilar

Details

If temporal = TRUE (default), the function constructs the confidence interval for the ordinal skewness relying on Theorem 7.1.1 in weiss2019distance;textualotsfeatures. Otherwise, the interval is constructed according to Theorem 4.1 in weiss2019distance;textualotsfeatures.

References

weiss2019distanceotsfeatures

Examples

Run this code
ci_skewness <- ci_ordinal_skewness(AustrianWages$data[[100]],
states = 0 : 5) # Constructing a confidence interval for the
# ordinal skewness for one OTS in dataset AustrianWages

Run the code above in your browser using DataLab