Learn R Programming

otsfeatures (version 1.0.0)

ordinal_dispersion_1: Computes the standard estimated dispersion of an ordinal time series

Description

ordinal_dispersion_1 computes the standard estimated dispersion of an ordinal time series

Usage

ordinal_dispersion_1(series, states, distance = "Block", normalize = FALSE)

Value

The standard estimated dispersion.

Arguments

series

An OTS.

states

A numerical vector containing the corresponding states.

distance

A function defining the underlying distance between states. The Hamming, block and Euclidean distances are already implemented by means of the arguments "Hamming", "Block" (default) and "Euclidean". Otherwise, a function taking as input two states must be provided.

normalize

Logical. If normalize = FALSE (default), the value of the standard estimated dispersion is returned. Otherwise, the function returns the normalized standard estimated dispersion.

Author

Ángel López-Oriona, José A. Vilar

Details

Given an OTS of length \(T\) with range \(\mathcal{S}=\{s_0, s_1, s_2, \ldots, s_n\}\) (\(s_0 < s_1 < s_2 < \ldots < s_n\)), \(\overline{X}_t=\{\overline{X}_1,\ldots, \overline{X}_T\}\), the function computes the standard estimated dispersion given by \(\widehat{disp}_{loc, d}=\frac{1}{T}\sum_{t=1}^Td\big(\overline{X}_t, \widehat{x}_{loc, d}\big)\), where \(\widehat{x}_{loc, d}\) is the standard estimate of the location and \(d(\cdot, \cdot)\) is a distance between ordinal states. If normalize = TRUE, then the normalized dispersion is computed, namely \(\widehat{disp}_{loc, d}/\)max\(_{s_i, s_j \in \mathcal{S}}d(s_i, s_j)\).

References

weiss2019distanceotsfeatures

Examples

Run this code
estimated_dispersion <- ordinal_dispersion_1(series = AustrianWages$data[[100]],
states = 0 : 5) # Computing the standard dispersion estimate
# for one series in dataset AustrianWages using the block distance

Run the code above in your browser using DataLab