Learn R Programming

otsfeatures (version 1.0.0)

ordinal_skewness: Computes the estimated skewness of an ordinal time series

Description

ordinal_skewness computes the estimated skewness of an ordinal time series

Usage

ordinal_skewness(series, states, distance = "Block", normalize = FALSE)

Value

The estimated skewness.

Arguments

series

An OTS.

states

A numerical vector containing the corresponding states.

distance

A function defining the underlying distance between states. The Hamming, block and Euclidean distances are already implemented by means of the arguments "Hamming", "Block" (default) and "Euclidean". Otherwise, a function taking as input two states must be provided.

normalize

Logical. If normalize = FALSE (default), the value of the estimated skewness is returned. Otherwise, the function returns the normalized estimated skewness.

Author

Ángel López-Oriona, José A. Vilar

Details

Given an OTS of length \(T\) with range \(\mathcal{S}=\{s_0, s_1, s_2, \ldots, s_n\}\) (\(s_0 < s_1 < s_2 < \ldots < s_n\)), \(\overline{X}_t=\{\overline{X}_1,\ldots, \overline{X}_T\}\), the function computes the estimated skewness given by \(\widehat{skew}_{d}=\sum_{i=0}^n\big(d(s_i,s_n)-d(s_i,s_0)\big)\widehat{p}_i\), where \(d(\cdot, \cdot)\) is a distance between ordinal states and \(\widehat{p}_k\) is the standard estimate of the marginal probability for state \(s_k\) computed from the realization \(\overline{X}_t\).

References

weiss2019distanceotsfeatures

Examples

Run this code
estimated_skewness <- ordinal_skewness(series = AustrianWages$data[[100]],
states = 0 : 5) # Computing the skewness estimate
# for one series in dataset AustrianWages using the block distance

Run the code above in your browser using DataLab