Learn R Programming

otsfeatures (version 1.0.0)

test_ordinal_skewness: Performs the hypothesis test associated with the ordinal skewness for the block distance

Description

test_ordinal_skewness performs the hypothesis test associated with the ordinal skewness for the block distance

Usage

test_ordinal_skewness(
  series,
  states,
  true_skewness,
  alpha = 0.05,
  temporal = TRUE,
  max_lag = 1
)

Value

The results of the hypothesis test.

Arguments

series

An OTS (numerical vector with integers).

states

A numeric vector containing the corresponding states.

true_skewness

The value for the true skewness.

alpha

The significance level (default is 0.05).

temporal

Logical. If temporal = TRUE (default), the test is performed for a time series. Otherwise, the test is performed for i.i.d. data.

max_lag

If temporal = TRUE, the maximum considered lag to compute the estimates related to the cumulative joint probabilities.

Author

Ángel López-Oriona, José A. Vilar

Details

If temporal = TRUE (default), the function performs the hypothesis test based on the ordinal skewness relying on Theorem 7.1.1 in weiss2019distance;textualotsfeatures. Otherwise, the test based on Theorem 4.1 in weiss2019distance;textualotsfeatures is carried out.

References

weiss2019distanceotsfeatures

Examples

Run this code
results_test <- test_ordinal_skewness(AustrianWages$data[[100]],
states = 0 : 5, true_skewness = 2) # Performing the hypothesis test associated with the
# ordinal skewness for one OTS in dataset AustrianWages

Run the code above in your browser using DataLab