Given an OTS of length \(T\) with range \(\mathcal{S}=\{s_0, s_1, s_2, \ldots, s_n\}\) (\(s_0 < s_1 < s_2 < \ldots < s_n\)),
\(\overline{X}_t=\{\overline{X}_1,\ldots, \overline{X}_T\}\), the function computes the DIVC
estimated dispersion given by \(\widehat{disp}_{d}=\frac{T}{T-1}\sum_{i,j=0}^nd\big(s_i, s_j\big)\widehat{p}_i\widehat{p}_j\),
where \(d(\cdot, \cdot)\) is a distance between ordinal states and \(\widehat{p}_k\) is the
standard estimate of the marginal probability for state \(s_k\).
If normalize = TRUE, and distance = "Block" or distance = "Euclidean", then the normalized versions are computed, that is,
the corresponding estimates are divided by the factors \(2/m\) or \(2/m^2\), respectively.